[Zope3-checkins] CVS: Zope3/src/zope/app/startup - bootstrap.py:1.19

Jim Fulton jim@zope.com
Sat, 21 Jun 2003 17:22:45 -0400


Update of /cvs-repository/Zope3/src/zope/app/startup
In directory cvs.zope.org:/tmp/cvs-serv2745/src/zope/app/startup

Modified Files:
	bootstrap.py 
Log Message:
Major refactoring to reflect change in terminology from
"configuration" to "registration" to refer to the configuration of how
objects are used (as opposed to their internal configuration).


=== Zope3/src/zope/app/startup/bootstrap.py 1.18 => 1.19 ===
--- Zope3/src/zope/app/startup/bootstrap.py:1.18	Thu Jun 12 13:03:45 2003
+++ Zope3/src/zope/app/startup/bootstrap.py	Sat Jun 21 17:22:14 2003
@@ -28,7 +28,7 @@
 from zope.app.services.servicenames import EventPublication, EventSubscription
 from zope.app.services.servicenames import ErrorLogging
 from zope.app.services.service import ServiceManager
-from zope.app.services.service import ServiceConfiguration
+from zope.app.services.service import ServiceRegistration
 from zope.app.services.hub import ObjectHub
 from zope.app.services.event import EventService
 from zope.app.services.errorr import ErrorReportingService
@@ -102,7 +102,7 @@
     """
     # The code here is complicated by the fact that the registry
     # calls at the end require a fully context-wrapped
     # configuration; hence all the traverse() and traverseName() calls.
     package_name = '/++etc++site/default'
     package = traverse(root_folder, package_name)
     name = service_type + '-1'
@@ -119,10 +119,10 @@
     """Configure a service in the root folder."""
     package_name = '/++etc++site/default'
     package = traverse(root_folder, package_name)
-    configuration_manager = package.getConfigurationManager()
-    configuration =  ServiceConfiguration(service_type,
-                                          name,
-                                          configuration_manager)
-    key = configuration_manager.setObject("", configuration)
-    configuration = traverseName(configuration_manager, key)
-    configuration.status = initial_status
+    registration_manager = package.getRegistrationManager()
+    registration =  ServiceRegistration(service_type,
+                                        name,
+                                        registration_manager)
+    key = registration_manager.setObject("", registration)
+    registration = traverseName(registration_manager, key)
+    registration.status = initial_status
@@ -102,7 +102,7 @@
     # The code here is complicated by the fact that the registry
     # calls at the end require a fully context-wrapped
-    # configuration; hence all the traverse() and traverseName() calls.
+    # registration; hence all the traverse() and traverseName() calls.
     package_name = '/++etc++site/default'
     package = traverse(root_folder, package_name)